@@ -493,6 +493,11 @@ def main(
                     click.echo(click.style(f"\t{module}: {errmsg}", fg="yellow"))
         else:
             click.echo(click.style("No revision found", fg="red"))
+            click.echo(
+                "For more detailed information about what command is doing, use `--verbose` option\n"
+                "For more information about how to specify criteria, see"
+                " https://evergreen-ci.github.io/git-co-evg-base/concepts/criteria/",
+            )
             sys.exit(1)
 
 
